@@ -9,7 +9,8 @@ EXT_TO_CONTENT_TYPE <- list(
   "tsv" = "text/tab-separated-values"
 )
 
-CONTENT_TYPE_TO_EXT <- structure(as.list(names(EXT_TO_CONTENT_TYPE)),
+CONTENT_TYPE_TO_EXT <- structure(
+  as.list(names(EXT_TO_CONTENT_TYPE)),
   .Names = unlist(EXT_TO_CONTENT_TYPE, use.names = FALSE)
 )
 
