@@ -1,14 +1,18 @@
 test_that("json_compare", {
   obj <- list(c = 1, b = list(list(2, 3), list(d = 9, f = 5)), a = 5)
   expect_false(json_compare(list(1, 2), list(2, 1))$equal)
-  expect_false(json_compare(
-    obj,
-    list(c = 1, b = list(list(3, 2), list(d = 9, f = 5)), a = 5)
-  )$equal)
-  expect_false(json_compare(
-    obj,
-    list(c = 1, b = list(list(d = 9, f = 5), list(2, 3)), a = 5)
-  )$equal)
+  expect_false(
+    json_compare(
+      obj,
+      list(c = 1, b = list(list(3, 2), list(d = 9, f = 5)), a = 5)
+    )$equal
+  )
+  expect_false(
+    json_compare(
+      obj,
+      list(c = 1, b = list(list(d = 9, f = 5), list(2, 3)), a = 5)
+    )$equal
+  )
 })
 
 public({
